==> tamejs-0.2.1.tgz: package/test/cases/2.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var slots = { } ;
    var n = 40 ;
    var assert = require ( "assert" ) ;
    
    exports [ "simple parallel twait" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_9 = function (__tame_k) {
            var i = 0 ;
            var __tame_fn_1 = function (__tame_k) {
                var __tame_fn_2 = function (__tame_k) {
                    var __tame_k_implicit =  {};
                    var __tame_fn_3 = function (__tame_k) {
                        if (i < n) {
                            var __tame_fn_4 = function (__tame_k) {
                                var __tame_fn_5 = function (__tame_k) {
                                    var __tame_ev = new tame.Event (__tame_k);
                                    var __tame_fn_6 = function (__tame_k) {
                                        setTimeout (
                                        __tame_ev.mkevent ()
                                        , 1 ) ;
                                        setTimeout (
                                        __tame_ev.mkevent ()
                                        , 2 ) ;
                                        tame.callChain([__tame_k]);
                                    };
                                    __tame_fn_6(tame.end);
                                    __tame_ev.trigger();
                                };
                                var __tame_fn_7 = function (__tame_k) {
                                    slots [ i ] = 1 ;
                                    i ++ ;
                                    tame.callChain([__tame_k]);
                                };
                                tame.callChain([__tame_fn_5, __tame_fn_7, __tame_k]);
                            };
                            tame.callChain([__tame_fn_4, __tame_fn_3, __tame_k]);
                        } else {
                            tame.callChain([__tame_k]);
                        }
                    };
                    __tame_k_implicit.k_break = __tame_k;
                    __tame_k_implicit.k_continue = function() { __tame_fn_3(__tame_k); };
                    tame.callChain([__tame_fn_3, __tame_k]);
                };
                var __tame_fn_8 = function (__tame_k) {
                    cb ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_2, __tame_fn_8, __tame_k]);
            };
            tame.callChain([__tame_fn_1, __tame_k]);
        };
        tame.callChain([__tame_fn_9, __tame_k]);
    }
    ,
    
    check :
    function  () {
         for (var i = 0 ; i < n ; i ++) {
            assert .ok ( slots [ i ] , "slot[" + i + "] is set" ) ;
        }
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);

==> tamejs-0.3.0.tgz: package/test/cases/2.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var slots = { } ;
    var n = 40 ;
    var assert = require ( "assert" ) ;
    
    exports [ "simple parallel await" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_9 = function (__tame_k) {
            var i = 0 ;
            var __tame_fn_1 = function (__tame_k) {
                var __tame_fn_2 = function (__tame_k) {
                    var __tame_k_implicit =  {};
                    var __tame_fn_3 = function (__tame_k) {
                        if (i < n) {
                            var __tame_fn_4 = function (__tame_k) {
                                var __tame_fn_5 = function (__tame_k) {
                                    var __tame_defers = new tame.Defers (__tame_k);
                                    var __tame_fn_6 = function (__tame_k) {
                                        setTimeout (
                                        __tame_defers.defer ()
                                        , 1 ) ;
                                        setTimeout (
                                        __tame_defers.defer ()
                                        , 2 ) ;
                                        tame.callChain([__tame_k]);
                                    };
                                    __tame_fn_6(tame.end);
                                    __tame_defers._fulfill();
                                };
                                var __tame_fn_7 = function (__tame_k) {
                                    slots [ i ] = 1 ;
                                    i ++ ;
                                    tame.callChain([__tame_k]);
                                };
                                tame.callChain([__tame_fn_5, __tame_fn_7, __tame_k]);
                            };
                            tame.callChain([__tame_fn_4, __tame_fn_3, __tame_k]);
                        } else {
                            tame.callChain([__tame_k]);
                        }
                    };
                    __tame_k_implicit.k_break = __tame_k;
                    __tame_k_implicit.k_continue = function() { __tame_fn_3(__tame_k); };
                    tame.callChain([__tame_fn_3, __tame_k]);
                };
                var __tame_fn_8 = function (__tame_k) {
                    cb ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_2, __tame_fn_8, __tame_k]);
            };
            tame.callChain([__tame_fn_1, __tame_k]);
        };
        tame.callChain([__tame_fn_9, __tame_k]);
    }
    ,
    
    check :
    function  () {
         for (var i = 0 ; i < n ; i ++) {
            assert . ok ( slots [ i ] , "slot[" + i + "] is set" ) ;
        }
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);
